package java.util.logging;

import java.nio.charset.IllegalCharsetNameException;
import java.io.UnsupportedEncodingException;
import java.nio.charset.Charset;

public abstract class Handler
{
    private static final int offValue;
    private final LogManager manager;
    private volatile Filter filter;
    private volatile Formatter formatter;
    private volatile Level logLevel;
    private volatile ErrorManager errorManager;
    private volatile String encoding;
    boolean sealed;
    
    protected Handler() {
        this.manager = LogManager.getLogManager();
        this.logLevel = Level.ALL;
        this.errorManager = new ErrorManager();
        this.sealed = true;
    }
    
    public abstract void publish(LogRecord p0);
    
    public abstract void flush();
    
    public abstract void close() throws SecurityException;
    
    public synchronized void setFormatter(Formatter formatter) throws SecurityException {
        this.checkPermission();
        formatter.getClass();
        this.formatter = formatter;
    }
    
    public Formatter getFormatter() {
        return this.formatter;
    }
    
    public synchronized void setEncoding(String s) throws SecurityException, UnsupportedEncodingException {
        this.checkPermission();
        if (s != null) {
            try {
                if (!Charset.isSupported(s)) {
                    throw new UnsupportedEncodingException(s);
                }
            }
            catch (IllegalCharsetNameException ex) {
                throw new UnsupportedEncodingException(s);
            }
        }
        this.encoding = s;
    }
    
    public String getEncoding() {
        return this.encoding;
    }
    
    public synchronized void setFilter(Filter filter) throws SecurityException {
        this.checkPermission();
        this.filter = filter;
    }
    
    public Filter getFilter() {
        return this.filter;
    }
    
    public synchronized void setErrorManager(ErrorManager errorManager) {
        this.checkPermission();
        if (errorManager == null) {
            throw new NullPointerException();
        }
        this.errorManager = errorManager;
        return;
    }
    
    public ErrorManager getErrorManager() {
        this.checkPermission();
        return this.errorManager;
    }
    
    protected void reportError(String s, Exception ex, int n) {
        try {
            this.errorManager.error(s, ex, n);
        }
        catch (Exception ex2) {
            System.err.println("Handler.reportError caught:");
            ex2.printStackTrace();
        }
    }
    
    public synchronized void setLevel(Level logLevel) throws SecurityException {
        if (logLevel == null) {
            throw new NullPointerException();
        }
        this.checkPermission();
        this.logLevel = logLevel;
        return;
    }
    
    public Level getLevel() {
        return this.logLevel;
    }
    
    public boolean isLoggable(LogRecord logRecord) {
        int intValue = this.getLevel().intValue();
        if (logRecord.getLevel().intValue() < intValue || intValue == Handler.offValue) {
            return false;
        }
        Filter filter = this.getFilter();
        return filter == null || filter.isLoggable(logRecord);
    }
    
    void checkPermission() throws SecurityException {
        if (this.sealed) {
            this.manager.checkPermission();
        }
    }
    
    static {
        offValue = Level.OFF.intValue();
    }
}
